sqlobject-cvs Mailing List for SQLObject (Page 104)
SQLObject is a Python ORM.
Brought to you by:
ianbicking,
phd
You can subscribe to this list here.
| 2003 |
Jan
|
Feb
|
Mar
(9) |
Apr
(74) |
May
(29) |
Jun
(16) |
Jul
(28) |
Aug
(10) |
Sep
(57) |
Oct
(9) |
Nov
(29) |
Dec
(12) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2004 |
Jan
(7) |
Feb
(14) |
Mar
(6) |
Apr
(3) |
May
(12) |
Jun
(34) |
Jul
(9) |
Aug
(29) |
Sep
(22) |
Oct
(2) |
Nov
(15) |
Dec
(52) |
| 2005 |
Jan
(47) |
Feb
(78) |
Mar
(14) |
Apr
(35) |
May
(33) |
Jun
(16) |
Jul
(26) |
Aug
(63) |
Sep
(40) |
Oct
(96) |
Nov
(96) |
Dec
(123) |
| 2006 |
Jan
(159) |
Feb
(144) |
Mar
(64) |
Apr
(31) |
May
(88) |
Jun
(48) |
Jul
(16) |
Aug
(64) |
Sep
(87) |
Oct
(92) |
Nov
(56) |
Dec
(76) |
| 2007 |
Jan
(94) |
Feb
(103) |
Mar
(126) |
Apr
(123) |
May
(85) |
Jun
(11) |
Jul
(130) |
Aug
(47) |
Sep
(65) |
Oct
(70) |
Nov
(12) |
Dec
(11) |
| 2008 |
Jan
(30) |
Feb
(55) |
Mar
(88) |
Apr
(20) |
May
(50) |
Jun
|
Jul
(38) |
Aug
(1) |
Sep
(9) |
Oct
(5) |
Nov
(6) |
Dec
(39) |
| 2009 |
Jan
(8) |
Feb
(16) |
Mar
(3) |
Apr
(33) |
May
(44) |
Jun
(1) |
Jul
(10) |
Aug
(33) |
Sep
(74) |
Oct
(22) |
Nov
|
Dec
(15) |
| 2010 |
Jan
(28) |
Feb
(22) |
Mar
(46) |
Apr
(29) |
May
(1) |
Jun
(1) |
Jul
(27) |
Aug
(8) |
Sep
(5) |
Oct
(33) |
Nov
(24) |
Dec
(41) |
| 2011 |
Jan
(4) |
Feb
(12) |
Mar
(35) |
Apr
(29) |
May
(19) |
Jun
(16) |
Jul
(32) |
Aug
(25) |
Sep
(5) |
Oct
(11) |
Nov
(21) |
Dec
(12) |
| 2012 |
Jan
(3) |
Feb
(4) |
Mar
(20) |
Apr
(4) |
May
(25) |
Jun
(13) |
Jul
|
Aug
|
Sep
(2) |
Oct
(25) |
Nov
(9) |
Dec
(1) |
| 2013 |
Jan
(6) |
Feb
(8) |
Mar
|
Apr
(10) |
May
(31) |
Jun
(7) |
Jul
(18) |
Aug
(33) |
Sep
(4) |
Oct
(16) |
Nov
|
Dec
(27) |
| 2014 |
Jan
(2) |
Feb
|
Mar
|
Apr
(11) |
May
(39) |
Jun
(8) |
Jul
(11) |
Aug
(4) |
Sep
|
Oct
(27) |
Nov
|
Dec
(71) |
| 2015 |
Jan
(17) |
Feb
(47) |
Mar
(33) |
Apr
|
May
|
Jun
(9) |
Jul
(7) |
Aug
|
Sep
|
Oct
|
Nov
|
Dec
(8) |
| 2016 |
Jan
(4) |
Feb
(4) |
Mar
|
Apr
|
May
(12) |
Jun
(7) |
Jul
(9) |
Aug
(31) |
Sep
(8) |
Oct
(3) |
Nov
(15) |
Dec
(1) |
| 2017 |
Jan
(13) |
Feb
(7) |
Mar
(14) |
Apr
(8) |
May
(10) |
Jun
(4) |
Jul
(2) |
Aug
(1) |
Sep
|
Oct
(8) |
Nov
(4) |
Dec
(5) |
| 2018 |
Jan
(2) |
Feb
(8) |
Mar
|
Apr
(4) |
May
|
Jun
(6) |
Jul
|
Aug
(1) |
Sep
|
Oct
|
Nov
(1) |
Dec
|
| 2019 |
Jan
(1) |
Feb
(16) |
Mar
(1) |
Apr
(3) |
May
(5) |
Jun
(1) |
Jul
|
Aug
|
Sep
(2) |
Oct
|
Nov
(1) |
Dec
(3) |
| 2020 |
Jan
|
Feb
|
Mar
|
Apr
(1) |
May
(1) |
Jun
|
Jul
|
Aug
(1) |
Sep
|
Oct
(2) |
Nov
|
Dec
(2) |
| 2021 |
Jan
|
Feb
(2) |
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
(1) |
Nov
(1) |
Dec
|
| 2022 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(6) |
Oct
(1) |
Nov
(1) |
Dec
(4) |
| 2023 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
(1) |
Aug
(3) |
Sep
(2) |
Oct
(2) |
Nov
(4) |
Dec
|
| 2024 |
Jan
|
Feb
(2) |
Mar
|
Apr
|
May
|
Jun
|
Jul
(1) |
Aug
|
Sep
(1) |
Oct
|
Nov
|
Dec
(9) |
| 2025 |
Jan
|
Feb
(4) |
Mar
(2) |
Apr
|
May
|
Jun
|
Jul
|
Aug
(1) |
Sep
|
Oct
|
Nov
(2) |
Dec
(2) |
|
From: <sub...@co...> - 2007-02-20 16:02:07
|
Author: phd
Date: 2007-02-20 09:01:44 -0700 (Tue, 20 Feb 2007)
New Revision: 2330
Modified:
home/phd/SQLObject/paramstyles/sqlobject/manager/command.py
Log:
Merged patches from the revisions 2324:2329 from the trunk
Modified: home/phd/SQLObject/paramstyles/sqlobject/manager/command.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/manager/command.py 2007-02-20 15:51:16 UTC (rev 2329)
+++ home/phd/SQLObject/paramstyles/sqlobject/manager/command.py 2007-02-20 16:01:44 UTC (rev 2330)
@@ -580,14 +580,14 @@
if self.options.interactive:
if self.ask('Create %s' % soClass.__name__):
created += 1
- tableConstraints = soClass.createTable()
+ tableConstraints = soClass.createTable(applyConstraints=False)
if tableConstraints:
constraints[soClass._connection].append(tableConstraints)
else:
print 'Cancelled'
else:
created += 1
- tableConstraints = soClass.createTable()
+ tableConstraints = soClass.createTable(applyConstraints=False)
if tableConstraints:
constraints[soClass._connection].append(tableConstraints)
for connection in constraints.keys():
|
|
From: SourceForge.net <no...@so...> - 2007-02-20 15:58:51
|
Bugs item #1663785, was opened at 2007-02-19 22:49 Message generated for change (Comment added) made by phd You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540672&aid=1663785&group_id=74338 Please note that this message will contain a full copy of the comment thread, including the initial issue submission, for this request, not just the latest update. Category: MySQL Group: SQLObject from repository Status: Open >Resolution: Accepted Priority: 5 Private: No Submitted By: dado1945 (dado1945) >Assigned to: Oleg Broytmann (phd) Summary: ADD CONSTRAINT fails Initial Comment: Environment: Windows, MySql 5.0, SQLObject from svn Description: (1) It seems SQLObject creates tables alphabetically and adds constraints after creation of each table. It might happen that required table is not created yet for constraint. It is interesting that "sql sql" shows that constraints will be added after all tables are created. (2) Another problem is that foreign key and id has different types (INT and INT UNSIGNED). Because of those two problems constrain creation fails. E.g. this query: ALTER TABLE blog ADD CONSTRAINT blog_language_id_exists FOREIGN KEY (language_id) REFERENCES language (id) gives following error: sqlobject.dberrors.OperationalError: Can't create table '.\tp\#sql-1b8_35.frm' (errno: 150) (1) This problem might be solved by changing line 590 in file sqlobject\manager\command.py: tableConstraints = soClass.createTable() to: tableConstraints = soClass.createTable(applyConstraints=False) I guess the same fix is required by line 583. (2) I think foreign key type must be changed to UNSIGNED INT but I have not found part where to do that. Because of that I just removed UNSIGNED from sqlobject\mysql\mysqlconnection.py line 172. That's not the best fix but the fastest one I have found. Note: I guess this problem might exist for some other databases as well. ---------------------------------------------------------------------- >Comment By: Oleg Broytmann (phd) Date: 2007-02-20 18:58 Message: Logged In: YES user_id=4799 Originator: NO 1. Fixed in the SVN, revision 2329. 2. In the MySQL Reference Manual there is an example: CREATE TABLE parent(id INT NOT NULL, PRIMARY KEY (id) ) TYPE=INNODB; CREATE TABLE child(id INT, parent_id INT, INDEX par_ind (parent_id), FOREIGN KEY (parent_id) REFERENCES parent(id) ON DELETE CASCADE ) TYPE=INNODB; So it seems a foreign keys have no obligation to be UNSIGNED. Why do you think they *must* be UNSIGNED? ---------------------------------------------------------------------- You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540672&aid=1663785&group_id=74338 |
|
From: <sub...@co...> - 2007-02-20 15:51:28
|
Author: phd
Date: 2007-02-20 08:51:16 -0700 (Tue, 20 Feb 2007)
New Revision: 2329
Modified:
SQLObject/trunk/sqlobject/manager/command.py
Log:
Fix N1 for the bug 1663785: ADD CONSTRAINT fails - do not apply constraints
immediately - apply them after all tables has been created.
Modified: SQLObject/trunk/sqlobject/manager/command.py
===================================================================
--- SQLObject/trunk/sqlobject/manager/command.py 2007-02-20 15:31:55 UTC (rev 2328)
+++ SQLObject/trunk/sqlobject/manager/command.py 2007-02-20 15:51:16 UTC (rev 2329)
@@ -186,7 +186,7 @@
# This abstract base class
return
register(cls)
-
+
def __init__(self, invoked_as, command_name, args, runner):
self.invoked_as = invoked_as
self.command_name = command_name
@@ -394,7 +394,7 @@
continue
classes = self.classes_from_module(module)
all.extend(classes)
-
+
os.path.walk(package_dir, find_classes_in_file, None)
return all
@@ -419,7 +419,7 @@
dir = conf['history_dir']
dir = dir.replace('$base', dist.location)
self.options.output_dir = dir
-
+
def config_from_egg(self, egg_spec, warn_no_sqlobject=True):
import pkg_resources
dist = pkg_resources.get_distribution(egg_spec)
@@ -514,8 +514,8 @@
for constraint in constraints:
if constraint:
print constraint.strip() + ';\n'
-
+
class CommandList(Command):
name = 'list'
@@ -580,14 +580,14 @@
if self.options.interactive:
if self.ask('Create %s' % soClass.__name__):
created += 1
- tableConstraints = soClass.createTable()
+ tableConstraints = soClass.createTable(applyConstraints=False)
if tableConstraints:
constraints[soClass._connection].append(tableConstraints)
else:
print 'Cancelled'
else:
created += 1
- tableConstraints = soClass.createTable()
+ tableConstraints = soClass.createTable(applyConstraints=False)
if tableConstraints:
constraints[soClass._connection].append(tableConstraints)
for connection in constraints.keys():
@@ -600,8 +600,8 @@
if v >= 1:
print '%i tables created (%i already exist)' % (
created, existing)
-
+
class CommandDrop(Command):
name = 'drop'
@@ -802,7 +802,7 @@
'database is currently at. Use the upgrade command to '
'sync databases with code.'
% SQLObjectVersionTable.sqlmeta.table)
-
+
parser = standard_parser()
parser.add_option('--output-dir',
help="Base directory for recorded definitions",
@@ -845,7 +845,7 @@
if self.options.force_db_version:
self.command_force_db_version()
return
-
+
v = self.options.verbose
sim = self.options.simulate
classes = self.classes()
@@ -988,7 +988,7 @@
def strip_comments(self, sql):
lines = [l for l in sql.splitlines()
if not l.strip().startswith('--')]
- return '\n'.join(lines)
+ return '\n'.join(lines)
def base_dir(self):
base = self.options.output_dir
@@ -1003,7 +1003,7 @@
def find_output_dir(self):
today = time.strftime('%Y-%m-%d', time.localtime())
if self.options.version_name:
- dir = os.path.join(self.base_dir(), today + '-' +
+ dir = os.path.join(self.base_dir(), today + '-' +
self.options.version_name)
if os.path.exists(dir):
print ("Error, directory already exists: %s"
@@ -1019,7 +1019,7 @@
extra = 'a'
else:
extra = chr(ord(extra)+1)
-
+
def find_last_version(self):
names = []
for fn in os.listdir(self.base_dir()):
@@ -1116,8 +1116,8 @@
raise
self.update_db(next_version, conn)
print 'Done.'
-
+
def current_version(self):
conn = self.connection()
if not conn.tableExists(SQLObjectVersionTable.sqlmeta.table):
@@ -1177,8 +1177,8 @@
print 'No upgraders found in %s' % current_dir
return None, None
upgraders.sort()
- return upgraders[-1]
-
+ return upgraders[-1]
+
def update_sys_path(paths, verbose):
if isinstance(paths, (str, unicode)):
paths = [paths]
|
|
From: <sub...@co...> - 2007-02-20 15:27:31
|
Author: luke Date: 2007-02-20 08:27:18 -0700 (Tue, 20 Feb 2007) New Revision: 2327 Added: SQLObject/branches/sqlbuilder-views/ Log: Create branch for sqlbuilder views Copied: SQLObject/branches/sqlbuilder-views (from rev 2326, SQLObject/trunk) |
|
From: SourceForge.net <no...@so...> - 2007-02-20 02:33:15
|
Patches item #1660094, was opened at 2007-02-14 16:02 Message generated for change (Comment added) made by lukeopperman You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 Please note that this message will contain a full copy of the comment thread, including the initial issue submission, for this request, not just the latest update. Category: None Group: None Status: Open Resolution: None Priority: 5 Private: No Submitted By: Luke Opperman (lukeopperman) Assigned to: Nobody/Anonymous (nobody) >Summary: Internal SQLBuilder use / ViewSQLObject Initial Comment: Ok, first-look patch for the discussion at http://comments.gmane.org/gmane.comp.python.sqlobject/7819 This was originally entered in Trac but it is currently down - this SF patch should supersede Trac #291. This also is an alternate resolution to SF Patch 1432078, "Add DISTINCT to sqlbuilder.py Select". This includes changes to Aliases and SQLJoins to properly handle sqlrepr'ing Alias(Select()) instances (and more generally, use sqlrepr to construct the join sqlrepr). But see item #2 below. All tests pass for me on postgres except where noted in the diff. This patch is probably NOT ready to be applied for the following hack-ish reasons: 1. sqlbuilder.Select LIMIT/OFFSET for db-specific formats - this was previously implemented in dbconnection-specific method "_queryAddLimitOffset" (only postgres and mysql override this today), should probably instead become a SQLExpression with a custom converter that implements these differences. 2. There's a fundamental issue with the current sqlbuilder.SQLExpression, where in several instances (AliasField.tablesUsedImmediate for instance) objects that may be SQLExpression instances are indiscriminately converted to strings, ie "%s %s %s % (self.tableName self.as_string, self.alias) when self.tableName is actually a Select instance. SQLExpression.__str__ calls .__sqlrepr__(None), which means that earlier than necessary we've lost the ability to format queries for the db they eventually run on (in the exposing case for me, I have Select(... clause=X.q.boolCol==True) and True is not properly formatted for the db. My recommendation for fixing #2 is to change these str-casts to sqlrepr(x, db), which will require tablesUsedImmediate accepting a db argument. This patch takes a lazier approach that lets me move forward, creating a module-level variable to override the None used in the __str__/__repr__ call mentioned above. ---------------------------------------------------------------------- >Comment By: Luke Opperman (lukeopperman) Date: 2007-02-19 20:33 Message: Logged In: YES user_id=700949 Originator: YES File Added: sresults-views-20070219-2.diff ---------------------------------------------------------------------- Comment By: Luke Opperman (lukeopperman) Date: 2007-02-19 20:32 Message: Logged In: YES user_id=700949 Originator: YES File Added: sresults-selectOne-20060217.diff ---------------------------------------------------------------------- You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 |
|
From: SourceForge.net <no...@so...> - 2007-02-20 02:32:23
|
Patches item #1660094, was opened at 2007-02-14 16:02 Message generated for change (Comment added) made by lukeopperman You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 Please note that this message will contain a full copy of the comment thread, including the initial issue submission, for this request, not just the latest update. Category: None Group: None Status: Open Resolution: None Priority: 5 Private: No Submitted By: Luke Opperman (lukeopperman) Assigned to: Nobody/Anonymous (nobody) Summary: SelectResults / DBConnection.queryForSelect use sqlbuilder Initial Comment: Ok, first-look patch for the discussion at http://comments.gmane.org/gmane.comp.python.sqlobject/7819 This was originally entered in Trac but it is currently down - this SF patch should supersede Trac #291. This also is an alternate resolution to SF Patch 1432078, "Add DISTINCT to sqlbuilder.py Select". This includes changes to Aliases and SQLJoins to properly handle sqlrepr'ing Alias(Select()) instances (and more generally, use sqlrepr to construct the join sqlrepr). But see item #2 below. All tests pass for me on postgres except where noted in the diff. This patch is probably NOT ready to be applied for the following hack-ish reasons: 1. sqlbuilder.Select LIMIT/OFFSET for db-specific formats - this was previously implemented in dbconnection-specific method "_queryAddLimitOffset" (only postgres and mysql override this today), should probably instead become a SQLExpression with a custom converter that implements these differences. 2. There's a fundamental issue with the current sqlbuilder.SQLExpression, where in several instances (AliasField.tablesUsedImmediate for instance) objects that may be SQLExpression instances are indiscriminately converted to strings, ie "%s %s %s % (self.tableName self.as_string, self.alias) when self.tableName is actually a Select instance. SQLExpression.__str__ calls .__sqlrepr__(None), which means that earlier than necessary we've lost the ability to format queries for the db they eventually run on (in the exposing case for me, I have Select(... clause=X.q.boolCol==True) and True is not properly formatted for the db. My recommendation for fixing #2 is to change these str-casts to sqlrepr(x, db), which will require tablesUsedImmediate accepting a db argument. This patch takes a lazier approach that lets me move forward, creating a module-level variable to override the None used in the __str__/__repr__ call mentioned above. ---------------------------------------------------------------------- >Comment By: Luke Opperman (lukeopperman) Date: 2007-02-19 20:32 Message: Logged In: YES user_id=700949 Originator: YES File Added: sresults-selectOne-20060217.diff ---------------------------------------------------------------------- You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 |
|
From: SourceForge.net <no...@so...> - 2007-02-19 19:49:04
|
Bugs item #1663785, was opened at 2007-02-19 21:49 Message generated for change (Tracker Item Submitted) made by Item Submitter You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540672&aid=1663785&group_id=74338 Please note that this message will contain a full copy of the comment thread, including the initial issue submission, for this request, not just the latest update. Category: MySQL Group: SQLObject from repository Status: Open Resolution: None Priority: 5 Private: No Submitted By: dado1945 (dado1945) Assigned to: Nobody/Anonymous (nobody) Summary: ADD CONSTRAINT fails Initial Comment: Environment: Windows, MySql 5.0, SQLObject from svn Description: (1) It seems SQLObject creates tables alphabetically and adds constraints after creation of each table. It might happen that required table is not created yet for constraint. It is interesting that "sql sql" shows that constraints will be added after all tables are created. (2) Another problem is that foreign key and id has different types (INT and INT UNSIGNED). Because of those two problems constrain creation fails. E.g. this query: ALTER TABLE blog ADD CONSTRAINT blog_language_id_exists FOREIGN KEY (language_id) REFERENCES language (id) gives following error: sqlobject.dberrors.OperationalError: Can't create table '.\tp\#sql-1b8_35.frm' (errno: 150) (1) This problem might be solved by changing line 590 in file sqlobject\manager\command.py: tableConstraints = soClass.createTable() to: tableConstraints = soClass.createTable(applyConstraints=False) I guess the same fix is required by line 583. (2) I think foreign key type must be changed to UNSIGNED INT but I have not found part where to do that. Because of that I just removed UNSIGNED from sqlobject\mysql\mysqlconnection.py line 172. That's not the best fix but the fastest one I have found. Note: I guess this problem might exist for some other databases as well. ---------------------------------------------------------------------- You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540672&aid=1663785&group_id=74338 |
|
From: <sub...@co...> - 2007-02-19 19:47:19
|
Author: phd
Date: 2007-02-19 12:47:10 -0700 (Mon, 19 Feb 2007)
New Revision: 2324
Removed:
home/phd/SQLObject/paramstyles/sqlobject/tests/test_basic_old.py
home/phd/SQLObject/paramstyles/sqlobject/tests/test_joins_old.py
home/phd/SQLObject/paramstyles/sqlobject/tests/test_sorting_old.py
home/phd/SQLObject/paramstyles/sqlobject/tests/test_stringid_old.py
home/phd/SQLObject/paramstyles/sqlobject/tests/test_style_old.py
Modified:
home/phd/SQLObject/paramstyles/sqlobject/main.py
home/phd/SQLObject/paramstyles/sqlobject/tests/test_auto_old.py
Log:
Merged patches from the revisions 2321:2323 from the trunk
Modified: home/phd/SQLObject/paramstyles/sqlobject/main.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_auto_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_auto_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -7,64 +7,7 @@
except ImportError:
from mx.DateTime import now
-deprecated_module()
-
########################################
-## Dynamic column tests
-########################################
-
-class OldPerson(SQLObject):
-
- class sqlmeta:
- defaultOrder = 'name'
- _columns = [StringCol('name', length=100, dbName='name_col')]
-
-class OldPhone(SQLObject):
-
- class sqlmeta:
- defaultOrder = 'phone'
- _columns = [StringCol('phone', length=12)]
-
-class TestPeople:
-
- def setup_method(self, meth):
- setupClass(OldPerson, force=True)
- setupClass(OldPhone, force=True)
- for n in ['jane', 'tim', 'bob', 'jake']:
- OldPerson(name=n)
- for p in ['555-555-5555', '555-394-2930',
- '444-382-4854']:
- OldPhone(phone=p)
-
- def test_defaultOrder(self):
- assert (list(OldPerson.select('all')) ==
- list(OldPerson.select('all', orderBy=OldPerson.sqlmeta.defaultOrder)))
-
- def test_dynamicColumn(self):
- nickname = StringCol('nickname', length=10)
- OldPerson.addColumn(nickname, changeSchema=True)
- n = OldPerson(name='robert', nickname='bob')
- assert ([p.name for p in OldPerson.select('all')]
- == ['bob', 'jake', 'jane', 'robert', 'tim'])
- OldPerson.delColumn(nickname, changeSchema=True)
-
- def test_dynamicJoin(self):
- col = KeyCol('oldPerson', foreignKey='OldPerson')
- OldPhone.addColumn(col, changeSchema=True)
- join = MultipleJoin('OldPhone')
- OldPerson.addJoin(join)
- for phone in OldPhone.select('all'):
- if phone.phone.startswith('555'):
- phone.oldPerson = OldPerson.selectBy(name='tim')[0]
- else:
- phone.oldPerson = OldPerson.selectBy(name='bob')[0]
- l = [p.phone for p in OldPerson.selectBy(name='tim')[0].oldPhones]
- l.sort()
- assert l == ['555-394-2930', '555-555-5555']
- OldPhone.delColumn(col, changeSchema=True)
- OldPerson.delJoin(join)
-
-########################################
## Auto class generation
########################################
@@ -184,4 +127,3 @@
OldAutoTest.sqlmeta.registry).classes['OldAutoTest']
teardown_module()
-
Deleted: home/phd/SQLObject/paramstyles/sqlobject/tests/test_basic_old.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_basic_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_basic_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -1,50 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-class OldTestSO1(SQLObject):
-
- name = StringCol(length=50, dbName='name_col')
- _cacheValues = False
- _columns = [
- StringCol('passwd', length=10),
- ]
-
- def _set_passwd(self, passwd):
- self._SO_set_passwd(passwd.encode('rot13'))
-
-def setupGetters(cls):
- setupClass(cls)
- inserts(cls, [('bob', 'god'), ('sally', 'sordid'),
- ('dave', 'dremel'), ('fred', 'forgo')],
- 'name passwd')
-
-def test_case1():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- assert bob.name == 'bob'
- assert bob.passwd == 'god'.encode('rot13')
-
-def test_newline():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- testString = 'hey\nyou\\can\'t you see me?\t'
- bob.name = testString
- bob.expire()
- assert bob.name == testString
-
-def test_count():
- setupGetters(OldTestSO1)
- assert OldTestSO1.selectBy(name='bob').count() == 1
- assert OldTestSO1.select(OldTestSO1.q.name == 'bob').count() == 1
- assert OldTestSO1.select().count() == len(list(OldTestSO1.select()))
-
-def test_getset():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- assert bob.name == 'bob'
- bob.name = 'joe'
- assert bob.name == 'joe'
-
-teardown_module()
Deleted: home/phd/SQLObject/paramstyles/sqlobject/tests/test_joins_old.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_joins_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_joins_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -1,116 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-########################################
-## Joins
-########################################
-
-class OldPersonJoiner(SQLObject):
-
- name = StringCol(length=40, alternateID=True)
- _joins = [RelatedJoin('OldAddressJoiner')]
-
-class OldAddressJoiner(SQLObject):
-
- zip = StringCol(length=5, alternateID=True)
- _joins = [RelatedJoin('OldPersonJoiner')]
-
-class OldImplicitJoiningSO(SQLObject):
- foo = RelatedJoin('Bar')
-
-class OldExplicitJoiningSO(SQLObject):
- _joins = [MultipleJoin('Bar', joinMethodName='foo')]
-
-class TestJoin:
-
- def setup_method(self, meth):
- setupClass(OldPersonJoiner)
- setupClass(OldAddressJoiner)
- print "CLEARED"
- for n in ['bob', 'tim', 'jane', 'joe', 'fred', 'barb']:
- OldPersonJoiner(name=n)
- for z in ['11111', '22222', '33333', '44444']:
- OldAddressJoiner(zip=z)
- print "INSERTED"
-
- def test_join(self):
- b = OldPersonJoiner.byName('bob')
- print b
- print b.oldAddressJoiners
- assert b.oldAddressJoiners == []
- z = OldAddressJoiner.byZip('11111')
- b.addOldAddressJoiner(z)
- self.assertZipsEqual(b.oldAddressJoiners, ['11111'])
- self.assertNamesEqual(z.oldPersonJoiners, ['bob'])
- z2 = OldAddressJoiner.byZip('22222')
- b.addOldAddressJoiner(z2)
- self.assertZipsEqual(b.oldAddressJoiners, ['11111', '22222'])
- self.assertNamesEqual(z2.oldPersonJoiners, ['bob'])
- b.removeOldAddressJoiner(z)
- self.assertZipsEqual(b.oldAddressJoiners, ['22222'])
- self.assertNamesEqual(z.oldPersonJoiners, [])
-
- def assertZipsEqual(self, zips, dest):
- assert [a.zip for a in zips] == dest
-
- def assertNamesEqual(self, people, dest):
- assert [p.name for p in people] == dest
-
- def test_joinAttributeWithUnderscores(self):
- # Make sure that the implicit setting of joinMethodName works
- assert hasattr(OldImplicitJoiningSO, 'foo')
- assert not hasattr(OldImplicitJoiningSO, 'bars')
-
- # And make sure explicit setting also works
- assert hasattr(OldExplicitJoiningSO, 'foo')
- assert not hasattr(OldExplicitJoiningSO, 'bars')
-
-class OldPersonJoiner2(SQLObject):
-
- name = StringCol('name', length=40, alternateID=True)
- _joins = [MultipleJoin('OldAddressJoiner2')]
-
-class OldAddressJoiner2(SQLObject):
-
- class sqlmeta:
- defaultOrder = ['-zip', 'plus4']
-
- zip = StringCol(length=5)
- plus4 = StringCol(length=4, default=None)
- oldPersonJoiner2 = ForeignKey('OldPersonJoiner2')
-
-class TestJoin2:
-
- def setup_method(self, meth):
- setupClass([OldPersonJoiner2, OldAddressJoiner2])
- p1 = OldPersonJoiner2(name='bob')
- p2 = OldPersonJoiner2(name='sally')
- for z in ['11111', '22222', '33333']:
- a = OldAddressJoiner2(zip=z, oldPersonJoiner2=p1)
- #p1.addOldAddressJoiner2(a)
- OldAddressJoiner2(zip='00000', oldPersonJoiner2=p2)
-
- def test_basic(self):
- bob = OldPersonJoiner2.byName('bob')
- sally = OldPersonJoiner2.byName('sally')
- assert len(bob.oldAddressJoiner2s) == 3
- assert len(sally.oldAddressJoiner2s) == 1
- bob.oldAddressJoiner2s[0].destroySelf()
- assert len(bob.oldAddressJoiner2s) == 2
- z = bob.oldAddressJoiner2s[0]
- z.zip = 'xxxxx'
- id = z.id
- del z
- z = OldAddressJoiner2.get(id)
- assert z.zip == 'xxxxx'
-
- def test_defaultOrder(self):
- p1 = OldPersonJoiner2.byName('bob')
- assert ([i.zip for i in p1.oldAddressJoiner2s]
- == ['33333', '22222', '11111'])
-
-
-teardown_module()
-
Deleted: home/phd/SQLObject/paramstyles/sqlobject/tests/test_sorting_old.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_sorting_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_sorting_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -1,36 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-class OldNames(SQLObject):
-
- _table = 'names_table'
-
- firstName = StringCol(length=30)
- lastName = StringCol(length=30)
-
- _defaultOrder = ['lastName', 'firstName']
-
-def setupNames():
- setupClass(OldNames)
- inserts(OldNames, [('aj', 'baker'), ('joe', 'robbins'),
- ('tim', 'jackson'), ('joe', 'baker'),
- ('zoe', 'robbins')],
- schema='firstName lastName')
-
-def nameList(names):
- result = []
- for name in names:
- result.append('%s %s' % (name.firstName, name.lastName))
- return result
-
-def firstList(names):
- return [n.firstName for n in names]
-
-def test_defaultOrder():
- setupNames()
- assert nameList(OldNames.select()) == \
- ['aj baker', 'joe baker',
- 'tim jackson', 'joe robbins',
- 'zoe robbins']
Deleted: home/phd/SQLObject/paramstyles/sqlobject/tests/test_stringid_old.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_stringid_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_stringid_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -1,73 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-########################################
-## String ID test
-########################################
-
-class OldSOStringID(SQLObject):
-
- _table = 'so_string_id'
- _idType = str
- val = StringCol(alternateID=True)
-
- mysqlCreate = """
- CREATE TABLE IF NOT EXISTS so_string_id (
- id VARCHAR(50) PRIMARY KEY,
- val TEXT
- )
- """
-
- postgresCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) PRIMARY KEY,
- val TEXT
- )
- """
-
- sybaseCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) UNIQUE,
- val VARCHAR(50) NULL
- )
- """
-
- mssqlCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) primary key,
- val VARCHAR(50) NULL
- )
- """
-
- firebirdCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) NOT NULL PRIMARY KEY,
- val BLOB SUB_TYPE TEXT
- )
- """
-
- sqliteCreate = postgresCreate
-
- mysqlDrop = """
- DROP TABLE IF EXISTS so_string_id
- """
-
- postgresDrop = """
- DROP TABLE so_string_id
- """
-
- sqliteDrop = postgresDrop
- firebirdDrop = postgresDrop
- mssqlDrop = postgresDrop
-
-
-def test_stringID():
- setupClass(OldSOStringID)
- t = OldSOStringID(id='hey', val='whatever')
- t2 = OldSOStringID.byVal('whatever')
- assert t == t2
- t3 = OldSOStringID(id='you', val='nowhere')
- t4 = OldSOStringID.get('you')
- assert t3 == t4
Deleted: home/phd/SQLObject/paramstyles/sqlobject/tests/test_style_old.py
===================================================================
--- home/phd/SQLObject/paramstyles/sqlobject/tests/test_style_old.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/tests/test_style_old.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -1,31 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-from sqlobject import styles
-
-deprecated_module()
-
-class AnotherStyle(styles.MixedCaseUnderscoreStyle):
- def pythonAttrToDBColumn(self, attr):
- if attr.lower().endswith('id'):
- return 'id'+styles.MixedCaseUnderscoreStyle.pythonAttrToDBColumn(self, attr[:-2])
- else:
- return styles.MixedCaseUnderscoreStyle.pythonAttrToDBColumn(self, attr)
-
-class OldSOStyleTest1(SQLObject):
- a = StringCol()
- st2 = ForeignKey('OldSOStyleTest2')
- _style = AnotherStyle()
-
-class OldSOStyleTest2(SQLObject):
- b = StringCol()
- _style = AnotherStyle()
-
-def test_style():
- setupClass([OldSOStyleTest2, OldSOStyleTest1])
- st1 = OldSOStyleTest1(a='something', st2=None)
- st2 = OldSOStyleTest2(b='whatever')
- st1.st2 = st2
- assert st1._columnDict['st2ID'].dbName == 'idst2'
- assert st1.st2 == st2
-
-teardown_module()
|
|
From: <sub...@co...> - 2007-02-19 19:45:55
|
Author: phd Date: 2007-02-19 12:45:50 -0700 (Mon, 19 Feb 2007) New Revision: 2323 Modified: SQLObject/docs/News.txt Log: Removed actively deprecated attributes; lowered deprecation level for other attributes to be removed after 0.9. Modified: SQLObject/docs/News.txt =================================================================== --- SQLObject/docs/News.txt 2007-02-19 19:41:03 UTC (rev 2322) +++ SQLObject/docs/News.txt 2007-02-19 19:45:50 UTC (rev 2323) @@ -15,6 +15,9 @@ * Support for Python 2.2 has been declared obsolete. +* Removed actively deprecated attributes; + lowered deprecation level for other attributes to be removed after 0.9. + * SQLite connection got columnsFromSchema(). Now all connections fully support fromDatabase. There are two version of columnsFromSchema() for SQLite - one parses the result of "SELECT sql FROM sqlite_master" and the other |
|
From: <sub...@co...> - 2007-02-19 19:41:17
|
Author: phd
Date: 2007-02-19 12:41:03 -0700 (Mon, 19 Feb 2007)
New Revision: 2322
Removed:
SQLObject/trunk/sqlobject/tests/test_basic_old.py
SQLObject/trunk/sqlobject/tests/test_joins_old.py
SQLObject/trunk/sqlobject/tests/test_sorting_old.py
SQLObject/trunk/sqlobject/tests/test_stringid_old.py
SQLObject/trunk/sqlobject/tests/test_style_old.py
Modified:
SQLObject/trunk/sqlobject/main.py
SQLObject/trunk/sqlobject/tests/test_auto_old.py
Log:
Removed actively deprecated attributes;
lowered deprecation level for other attributes to be removed after 0.9.
Modified: SQLObject/trunk/sqlobject/main.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_auto_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_auto_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -7,64 +7,7 @@
except ImportError:
from mx.DateTime import now
-deprecated_module()
-
########################################
-## Dynamic column tests
-########################################
-
-class OldPerson(SQLObject):
-
- class sqlmeta:
- defaultOrder = 'name'
- _columns = [StringCol('name', length=100, dbName='name_col')]
-
-class OldPhone(SQLObject):
-
- class sqlmeta:
- defaultOrder = 'phone'
- _columns = [StringCol('phone', length=12)]
-
-class TestPeople:
-
- def setup_method(self, meth):
- setupClass(OldPerson, force=True)
- setupClass(OldPhone, force=True)
- for n in ['jane', 'tim', 'bob', 'jake']:
- OldPerson(name=n)
- for p in ['555-555-5555', '555-394-2930',
- '444-382-4854']:
- OldPhone(phone=p)
-
- def test_defaultOrder(self):
- assert (list(OldPerson.select('all')) ==
- list(OldPerson.select('all', orderBy=OldPerson.sqlmeta.defaultOrder)))
-
- def test_dynamicColumn(self):
- nickname = StringCol('nickname', length=10)
- OldPerson.addColumn(nickname, changeSchema=True)
- n = OldPerson(name='robert', nickname='bob')
- assert ([p.name for p in OldPerson.select('all')]
- == ['bob', 'jake', 'jane', 'robert', 'tim'])
- OldPerson.delColumn(nickname, changeSchema=True)
-
- def test_dynamicJoin(self):
- col = KeyCol('oldPerson', foreignKey='OldPerson')
- OldPhone.addColumn(col, changeSchema=True)
- join = MultipleJoin('OldPhone')
- OldPerson.addJoin(join)
- for phone in OldPhone.select('all'):
- if phone.phone.startswith('555'):
- phone.oldPerson = OldPerson.selectBy(name='tim')[0]
- else:
- phone.oldPerson = OldPerson.selectBy(name='bob')[0]
- l = [p.phone for p in OldPerson.selectBy(name='tim')[0].oldPhones]
- l.sort()
- assert l == ['555-394-2930', '555-555-5555']
- OldPhone.delColumn(col, changeSchema=True)
- OldPerson.delJoin(join)
-
-########################################
## Auto class generation
########################################
@@ -184,4 +127,3 @@
OldAutoTest.sqlmeta.registry).classes['OldAutoTest']
teardown_module()
-
Deleted: SQLObject/trunk/sqlobject/tests/test_basic_old.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_basic_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_basic_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -1,50 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-class OldTestSO1(SQLObject):
-
- name = StringCol(length=50, dbName='name_col')
- _cacheValues = False
- _columns = [
- StringCol('passwd', length=10),
- ]
-
- def _set_passwd(self, passwd):
- self._SO_set_passwd(passwd.encode('rot13'))
-
-def setupGetters(cls):
- setupClass(cls)
- inserts(cls, [('bob', 'god'), ('sally', 'sordid'),
- ('dave', 'dremel'), ('fred', 'forgo')],
- 'name passwd')
-
-def test_case1():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- assert bob.name == 'bob'
- assert bob.passwd == 'god'.encode('rot13')
-
-def test_newline():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- testString = 'hey\nyou\\can\'t you see me?\t'
- bob.name = testString
- bob.expire()
- assert bob.name == testString
-
-def test_count():
- setupGetters(OldTestSO1)
- assert OldTestSO1.selectBy(name='bob').count() == 1
- assert OldTestSO1.select(OldTestSO1.q.name == 'bob').count() == 1
- assert OldTestSO1.select().count() == len(list(OldTestSO1.select()))
-
-def test_getset():
- setupGetters(OldTestSO1)
- bob = OldTestSO1.selectBy(name='bob')[0]
- assert bob.name == 'bob'
- bob.name = 'joe'
- assert bob.name == 'joe'
-
-teardown_module()
Deleted: SQLObject/trunk/sqlobject/tests/test_joins_old.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_joins_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_joins_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -1,116 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-########################################
-## Joins
-########################################
-
-class OldPersonJoiner(SQLObject):
-
- name = StringCol(length=40, alternateID=True)
- _joins = [RelatedJoin('OldAddressJoiner')]
-
-class OldAddressJoiner(SQLObject):
-
- zip = StringCol(length=5, alternateID=True)
- _joins = [RelatedJoin('OldPersonJoiner')]
-
-class OldImplicitJoiningSO(SQLObject):
- foo = RelatedJoin('Bar')
-
-class OldExplicitJoiningSO(SQLObject):
- _joins = [MultipleJoin('Bar', joinMethodName='foo')]
-
-class TestJoin:
-
- def setup_method(self, meth):
- setupClass(OldPersonJoiner)
- setupClass(OldAddressJoiner)
- print "CLEARED"
- for n in ['bob', 'tim', 'jane', 'joe', 'fred', 'barb']:
- OldPersonJoiner(name=n)
- for z in ['11111', '22222', '33333', '44444']:
- OldAddressJoiner(zip=z)
- print "INSERTED"
-
- def test_join(self):
- b = OldPersonJoiner.byName('bob')
- print b
- print b.oldAddressJoiners
- assert b.oldAddressJoiners == []
- z = OldAddressJoiner.byZip('11111')
- b.addOldAddressJoiner(z)
- self.assertZipsEqual(b.oldAddressJoiners, ['11111'])
- self.assertNamesEqual(z.oldPersonJoiners, ['bob'])
- z2 = OldAddressJoiner.byZip('22222')
- b.addOldAddressJoiner(z2)
- self.assertZipsEqual(b.oldAddressJoiners, ['11111', '22222'])
- self.assertNamesEqual(z2.oldPersonJoiners, ['bob'])
- b.removeOldAddressJoiner(z)
- self.assertZipsEqual(b.oldAddressJoiners, ['22222'])
- self.assertNamesEqual(z.oldPersonJoiners, [])
-
- def assertZipsEqual(self, zips, dest):
- assert [a.zip for a in zips] == dest
-
- def assertNamesEqual(self, people, dest):
- assert [p.name for p in people] == dest
-
- def test_joinAttributeWithUnderscores(self):
- # Make sure that the implicit setting of joinMethodName works
- assert hasattr(OldImplicitJoiningSO, 'foo')
- assert not hasattr(OldImplicitJoiningSO, 'bars')
-
- # And make sure explicit setting also works
- assert hasattr(OldExplicitJoiningSO, 'foo')
- assert not hasattr(OldExplicitJoiningSO, 'bars')
-
-class OldPersonJoiner2(SQLObject):
-
- name = StringCol('name', length=40, alternateID=True)
- _joins = [MultipleJoin('OldAddressJoiner2')]
-
-class OldAddressJoiner2(SQLObject):
-
- class sqlmeta:
- defaultOrder = ['-zip', 'plus4']
-
- zip = StringCol(length=5)
- plus4 = StringCol(length=4, default=None)
- oldPersonJoiner2 = ForeignKey('OldPersonJoiner2')
-
-class TestJoin2:
-
- def setup_method(self, meth):
- setupClass([OldPersonJoiner2, OldAddressJoiner2])
- p1 = OldPersonJoiner2(name='bob')
- p2 = OldPersonJoiner2(name='sally')
- for z in ['11111', '22222', '33333']:
- a = OldAddressJoiner2(zip=z, oldPersonJoiner2=p1)
- #p1.addOldAddressJoiner2(a)
- OldAddressJoiner2(zip='00000', oldPersonJoiner2=p2)
-
- def test_basic(self):
- bob = OldPersonJoiner2.byName('bob')
- sally = OldPersonJoiner2.byName('sally')
- assert len(bob.oldAddressJoiner2s) == 3
- assert len(sally.oldAddressJoiner2s) == 1
- bob.oldAddressJoiner2s[0].destroySelf()
- assert len(bob.oldAddressJoiner2s) == 2
- z = bob.oldAddressJoiner2s[0]
- z.zip = 'xxxxx'
- id = z.id
- del z
- z = OldAddressJoiner2.get(id)
- assert z.zip == 'xxxxx'
-
- def test_defaultOrder(self):
- p1 = OldPersonJoiner2.byName('bob')
- assert ([i.zip for i in p1.oldAddressJoiner2s]
- == ['33333', '22222', '11111'])
-
-
-teardown_module()
-
Deleted: SQLObject/trunk/sqlobject/tests/test_sorting_old.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_sorting_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_sorting_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -1,36 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-class OldNames(SQLObject):
-
- _table = 'names_table'
-
- firstName = StringCol(length=30)
- lastName = StringCol(length=30)
-
- _defaultOrder = ['lastName', 'firstName']
-
-def setupNames():
- setupClass(OldNames)
- inserts(OldNames, [('aj', 'baker'), ('joe', 'robbins'),
- ('tim', 'jackson'), ('joe', 'baker'),
- ('zoe', 'robbins')],
- schema='firstName lastName')
-
-def nameList(names):
- result = []
- for name in names:
- result.append('%s %s' % (name.firstName, name.lastName))
- return result
-
-def firstList(names):
- return [n.firstName for n in names]
-
-def test_defaultOrder():
- setupNames()
- assert nameList(OldNames.select()) == \
- ['aj baker', 'joe baker',
- 'tim jackson', 'joe robbins',
- 'zoe robbins']
Deleted: SQLObject/trunk/sqlobject/tests/test_stringid_old.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_stringid_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_stringid_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -1,73 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-deprecated_module()
-
-########################################
-## String ID test
-########################################
-
-class OldSOStringID(SQLObject):
-
- _table = 'so_string_id'
- _idType = str
- val = StringCol(alternateID=True)
-
- mysqlCreate = """
- CREATE TABLE IF NOT EXISTS so_string_id (
- id VARCHAR(50) PRIMARY KEY,
- val TEXT
- )
- """
-
- postgresCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) PRIMARY KEY,
- val TEXT
- )
- """
-
- sybaseCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) UNIQUE,
- val VARCHAR(50) NULL
- )
- """
-
- mssqlCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) primary key,
- val VARCHAR(50) NULL
- )
- """
-
- firebirdCreate = """
- CREATE TABLE so_string_id (
- id VARCHAR(50) NOT NULL PRIMARY KEY,
- val BLOB SUB_TYPE TEXT
- )
- """
-
- sqliteCreate = postgresCreate
-
- mysqlDrop = """
- DROP TABLE IF EXISTS so_string_id
- """
-
- postgresDrop = """
- DROP TABLE so_string_id
- """
-
- sqliteDrop = postgresDrop
- firebirdDrop = postgresDrop
- mssqlDrop = postgresDrop
-
-
-def test_stringID():
- setupClass(OldSOStringID)
- t = OldSOStringID(id='hey', val='whatever')
- t2 = OldSOStringID.byVal('whatever')
- assert t == t2
- t3 = OldSOStringID(id='you', val='nowhere')
- t4 = OldSOStringID.get('you')
- assert t3 == t4
Deleted: SQLObject/trunk/sqlobject/tests/test_style_old.py
===================================================================
--- SQLObject/trunk/sqlobject/tests/test_style_old.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/tests/test_style_old.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -1,31 +0,0 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-from sqlobject import styles
-
-deprecated_module()
-
-class AnotherStyle(styles.MixedCaseUnderscoreStyle):
- def pythonAttrToDBColumn(self, attr):
- if attr.lower().endswith('id'):
- return 'id'+styles.MixedCaseUnderscoreStyle.pythonAttrToDBColumn(self, attr[:-2])
- else:
- return styles.MixedCaseUnderscoreStyle.pythonAttrToDBColumn(self, attr)
-
-class OldSOStyleTest1(SQLObject):
- a = StringCol()
- st2 = ForeignKey('OldSOStyleTest2')
- _style = AnotherStyle()
-
-class OldSOStyleTest2(SQLObject):
- b = StringCol()
- _style = AnotherStyle()
-
-def test_style():
- setupClass([OldSOStyleTest2, OldSOStyleTest1])
- st1 = OldSOStyleTest1(a='something', st2=None)
- st2 = OldSOStyleTest2(b='whatever')
- st1.st2 = st2
- assert st1._columnDict['st2ID'].dbName == 'idst2'
- assert st1.st2 == st2
-
-teardown_module()
|
|
From: SourceForge.net <no...@so...> - 2007-02-14 22:02:53
|
Patches item #1660094, was opened at 2007-02-14 16:02 Message generated for change (Tracker Item Submitted) made by Item Submitter You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 Please note that this message will contain a full copy of the comment thread, including the initial issue submission, for this request, not just the latest update. Category: None Group: None Status: Open Resolution: None Priority: 5 Private: No Submitted By: Luke Opperman (lukeopperman) Assigned to: Nobody/Anonymous (nobody) Summary: SelectResults / DBConnection.queryForSelect use sqlbuilder Initial Comment: Ok, first-look patch for the discussion at http://comments.gmane.org/gmane.comp.python.sqlobject/7819 This was originally entered in Trac but it is currently down - this SF patch should supersede Trac #291. This also is an alternate resolution to SF Patch 1432078, "Add DISTINCT to sqlbuilder.py Select". This includes changes to Aliases and SQLJoins to properly handle sqlrepr'ing Alias(Select()) instances (and more generally, use sqlrepr to construct the join sqlrepr). But see item #2 below. All tests pass for me on postgres except where noted in the diff. This patch is probably NOT ready to be applied for the following hack-ish reasons: 1. sqlbuilder.Select LIMIT/OFFSET for db-specific formats - this was previously implemented in dbconnection-specific method "_queryAddLimitOffset" (only postgres and mysql override this today), should probably instead become a SQLExpression with a custom converter that implements these differences. 2. There's a fundamental issue with the current sqlbuilder.SQLExpression, where in several instances (AliasField.tablesUsedImmediate for instance) objects that may be SQLExpression instances are indiscriminately converted to strings, ie "%s %s %s % (self.tableName self.as_string, self.alias) when self.tableName is actually a Select instance. SQLExpression.__str__ calls .__sqlrepr__(None), which means that earlier than necessary we've lost the ability to format queries for the db they eventually run on (in the exposing case for me, I have Select(... clause=X.q.boolCol==True) and True is not properly formatted for the db. My recommendation for fixing #2 is to change these str-casts to sqlrepr(x, db), which will require tablesUsedImmediate accepting a db argument. This patch takes a lazier approach that lets me move forward, creating a module-level variable to override the None used in the __str__/__repr__ call mentioned above. ---------------------------------------------------------------------- You can respond by visiting: https://sourceforge.net/tracker/?func=detail&atid=540674&aid=1660094&group_id=74338 |
|
From: <sub...@co...> - 2007-02-13 11:32:53
|
Author: phd
Date: 2007-02-13 04:32:51 -0700 (Tue, 13 Feb 2007)
New Revision: 2294
Modified:
home/phd/SQLObject/paramstyles/setup.cfg
Log:
Merged patches from the revisions 2290:2293 from the trunk
Modified: home/phd/SQLObject/paramstyles/setup.cfg
===================================================================
--- home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 11:32:14 UTC (rev 2293)
+++ home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 11:32:51 UTC (rev 2294)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt docs/Versioning.txt
+ docs/Authors.txt docs/Versioning.txt docs/sqlobject-architecture.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 11:32:20
|
Author: phd
Date: 2007-02-13 04:32:14 -0700 (Tue, 13 Feb 2007)
New Revision: 2293
Modified:
SQLObject/tags/0.8.0/setup.cfg
Log:
Added docs/sqlobject-architecture.txt.
Modified: SQLObject/tags/0.8.0/setup.cfg
===================================================================
--- SQLObject/tags/0.8.0/setup.cfg 2007-02-13 11:31:43 UTC (rev 2292)
+++ SQLObject/tags/0.8.0/setup.cfg 2007-02-13 11:32:14 UTC (rev 2293)
@@ -7,7 +7,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt docs/Versioning.txt
+ docs/Authors.txt docs/Versioning.txt docs/sqlobject-architecture.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 11:31:49
|
Author: phd
Date: 2007-02-13 04:31:43 -0700 (Tue, 13 Feb 2007)
New Revision: 2292
Modified:
SQLObject/branches/0.8/setup.cfg
Log:
Added docs/sqlobject-architecture.txt.
Modified: SQLObject/branches/0.8/setup.cfg
===================================================================
--- SQLObject/branches/0.8/setup.cfg 2007-02-13 11:31:18 UTC (rev 2291)
+++ SQLObject/branches/0.8/setup.cfg 2007-02-13 11:31:43 UTC (rev 2292)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt docs/Versioning.txt
+ docs/Authors.txt docs/Versioning.txt docs/sqlobject-architecture.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 11:31:24
|
Author: phd
Date: 2007-02-13 04:31:18 -0700 (Tue, 13 Feb 2007)
New Revision: 2291
Modified:
SQLObject/trunk/setup.cfg
Log:
Added docs/sqlobject-architecture.txt.
Modified: SQLObject/trunk/setup.cfg
===================================================================
--- SQLObject/trunk/setup.cfg 2007-02-13 11:07:44 UTC (rev 2290)
+++ SQLObject/trunk/setup.cfg 2007-02-13 11:31:18 UTC (rev 2291)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt docs/Versioning.txt
+ docs/Authors.txt docs/Versioning.txt docs/sqlobject-architecture.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 11:08:03
|
Author: phd Date: 2007-02-13 04:07:44 -0700 (Tue, 13 Feb 2007) New Revision: 2290 Modified: home/phd/SQLObject/paramstyles/setup.cfg Log: Merged patches from the revisions 2288:2289 from the trunk Modified: home/phd/SQLObject/paramstyles/setup.cfg =================================================================== --- home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 11:06:21 UTC (rev 2289) +++ home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 11:07:44 UTC (rev 2290) @@ -34,6 +34,6 @@ make-dirs = 1 ## For live documentation: -doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ +# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ ## For in-development documentation: -# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ +doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ |
|
From: <sub...@co...> - 2007-02-13 11:06:40
|
Author: phd Date: 2007-02-13 04:06:21 -0700 (Tue, 13 Feb 2007) New Revision: 2289 Modified: SQLObject/trunk/setup.cfg Log: Docs from the trunk go to /devel/. Modified: SQLObject/trunk/setup.cfg =================================================================== --- SQLObject/trunk/setup.cfg 2007-02-13 10:51:11 UTC (rev 2288) +++ SQLObject/trunk/setup.cfg 2007-02-13 11:06:21 UTC (rev 2289) @@ -34,6 +34,6 @@ make-dirs = 1 ## For live documentation: -doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ +# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ ## For in-development documentation: -# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ +doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ |
|
From: <sub...@co...> - 2007-02-13 10:55:00
|
Author: phd Date: 2007-02-13 03:51:11 -0700 (Tue, 13 Feb 2007) New Revision: 2288 Modified: SQLObject/branches/0.7/docs/download.txt Log: SQLObject 0.7.3. Modified: SQLObject/branches/0.7/docs/download.txt =================================================================== --- SQLObject/branches/0.7/docs/download.txt 2007-02-13 10:40:20 UTC (rev 2287) +++ SQLObject/branches/0.7/docs/download.txt 2007-02-13 10:51:11 UTC (rev 2288) @@ -4,18 +4,18 @@ The latest releases are always available on the `Python Cheese Shop <http://cheeseshop.python.org/pypi/SQLObject>`_. -* `SQLObject 0.7.2 - <http://cheeseshop.python.org/packages/source/S/SQLObject/SQLObject-0.7.2.tar.gz>`_ +* `SQLObject 0.7.3 + <http://cheeseshop.python.org/packages/source/S/SQLObject/SQLObject-0.7.3.tar.gz>`_ (source package in ``tar.gz`` format) -* `0.7.2 Python 2.4 egg - <http://cheeseshop.python.org/packages/2.4/S/SQLObject/SQLObject-0.7.2-py2.4.egg>`_ +* `0.7.3 Python 2.4 egg + <http://cheeseshop.python.org/packages/2.4/S/SQLObject/SQLObject-0.7.3-py2.4.egg>`_ (`easy_install-friendly <http://peak.telecommunity.com/DevCenter/EasyInstall>`__ egg package) -* `0.7.2 Python 2.3 egg - <http://cheeseshop.python.org/packages/2.3/S/SQLObject/SQLObject-0.7.2-py2.3.egg>`_ +* `0.7.3 Python 2.3 egg + <http://cheeseshop.python.org/packages/2.3/S/SQLObject/SQLObject-0.7.3-py2.3.egg>`_ (`easy_install-friendly <http://peak.telecommunity.com/DevCenter/EasyInstall>`__ egg package) |
|
From: <sub...@co...> - 2007-02-13 10:40:25
|
Author: phd
Date: 2007-02-13 03:40:20 -0700 (Tue, 13 Feb 2007)
New Revision: 2287
Modified:
home/phd/SQLObject/paramstyles/setup.cfg
Log:
Merged patches from the revisions 2283:2286 from the trunk
Modified: home/phd/SQLObject/paramstyles/setup.cfg
===================================================================
--- home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 10:39:34 UTC (rev 2286)
+++ home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 10:40:20 UTC (rev 2287)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt
+ docs/Authors.txt docs/Versioning.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 10:39:45
|
Author: phd
Date: 2007-02-13 03:39:34 -0700 (Tue, 13 Feb 2007)
New Revision: 2286
Modified:
SQLObject/tags/0.8.0/setup.cfg
Log:
Added docs/Versioning.txt.
Modified: SQLObject/tags/0.8.0/setup.cfg
===================================================================
--- SQLObject/tags/0.8.0/setup.cfg 2007-02-13 10:39:12 UTC (rev 2285)
+++ SQLObject/tags/0.8.0/setup.cfg 2007-02-13 10:39:34 UTC (rev 2286)
@@ -7,7 +7,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt
+ docs/Authors.txt docs/Versioning.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 10:39:18
|
Author: phd
Date: 2007-02-13 03:39:12 -0700 (Tue, 13 Feb 2007)
New Revision: 2285
Modified:
SQLObject/branches/0.8/setup.cfg
Log:
Added docs/Versioning.txt.
Modified: SQLObject/branches/0.8/setup.cfg
===================================================================
--- SQLObject/branches/0.8/setup.cfg 2007-02-13 10:38:55 UTC (rev 2284)
+++ SQLObject/branches/0.8/setup.cfg 2007-02-13 10:39:12 UTC (rev 2285)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt
+ docs/Authors.txt docs/Versioning.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 10:39:02
|
Author: phd
Date: 2007-02-13 03:38:55 -0700 (Tue, 13 Feb 2007)
New Revision: 2284
Modified:
SQLObject/trunk/setup.cfg
Log:
Added docs/Versioning.txt.
Modified: SQLObject/trunk/setup.cfg
===================================================================
--- SQLObject/trunk/setup.cfg 2007-02-13 10:34:02 UTC (rev 2283)
+++ SQLObject/trunk/setup.cfg 2007-02-13 10:38:55 UTC (rev 2284)
@@ -11,7 +11,7 @@
docs/DeveloperGuide.txt docs/FAQ.txt docs/Inheritance.txt
docs/News.txt docs/SQLBuilder.txt docs/sqlobject-admin.txt
docs/community.txt docs/links.txt docs/download.txt
- docs/Authors.txt
+ docs/Authors.txt docs/Versioning.txt
doc_base = docs/
dest = docs/html
modules = sqlobject
|
|
From: <sub...@co...> - 2007-02-13 10:34:08
|
Author: phd Date: 2007-02-13 03:34:02 -0700 (Tue, 13 Feb 2007) New Revision: 2283 Modified: home/phd/SQLObject/paramstyles/setup.cfg Log: Merged patches from the revisions 2280:2282 from the trunk Modified: home/phd/SQLObject/paramstyles/setup.cfg =================================================================== --- home/phd/SQLObject/paramstyles/setup.cfg 2007-02-12 17:02:50 UTC (rev 2282) +++ home/phd/SQLObject/paramstyles/setup.cfg 2007-02-13 10:34:02 UTC (rev 2283) @@ -34,6 +34,6 @@ make-dirs = 1 ## For live documentation: -# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ +doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ ## For in-development documentation: -doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ +# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ |
|
From: <sub...@co...> - 2007-02-12 17:04:02
|
Author: ianb Date: 2007-02-12 10:02:50 -0700 (Mon, 12 Feb 2007) New Revision: 2282 Modified: SQLObject/trunk/setup.cfg Log: Put 0.8 docs at root Modified: SQLObject/trunk/setup.cfg =================================================================== --- SQLObject/trunk/setup.cfg 2007-02-12 14:12:45 UTC (rev 2281) +++ SQLObject/trunk/setup.cfg 2007-02-12 17:02:50 UTC (rev 2282) @@ -34,6 +34,6 @@ make-dirs = 1 ## For live documentation: -# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ +doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/ ## For in-development documentation: -doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ +# doc-dest = scp://ianbicking@shell.sf.net/home/groups/s/sq/sqlobject/htdocs/devel/ |
|
From: <sub...@co...> - 2007-02-12 14:12:57
|
Author: phd Date: 2007-02-12 07:12:45 -0700 (Mon, 12 Feb 2007) New Revision: 2281 Modified: SQLObject/tags/0.8.0/setup.cfg SQLObject/tags/0.8.0/setup.py Log: Version 0.8.0. Modified: SQLObject/tags/0.8.0/setup.cfg =================================================================== --- SQLObject/tags/0.8.0/setup.cfg 2007-02-12 14:09:53 UTC (rev 2280) +++ SQLObject/tags/0.8.0/setup.cfg 2007-02-12 14:12:45 UTC (rev 2281) @@ -1,10 +1,6 @@ [easy_install] #find_links = http://svn.pythonpaste.org/package_index.html -[egg_info] -tag_build = dev -tag_svn_revision = true - [pudge] theme = pythonpaste.org docs = docs/index.txt docs/SQLObject.txt docs/TODO.txt Modified: SQLObject/tags/0.8.0/setup.py =================================================================== --- SQLObject/tags/0.8.0/setup.py 2007-02-12 14:09:53 UTC (rev 2280) +++ SQLObject/tags/0.8.0/setup.py 2007-02-12 14:12:45 UTC (rev 2281) @@ -28,7 +28,7 @@ """ setup(name="SQLObject", - version="0.8", + version="0.8.0", description="Object-Relational Manager, aka database wrapper", long_description="""\ SQLObject is a popular *Object Relational Manager* for providing an |
--- home/phd/SQLObject/paramstyles/sqlobject/main.py 2007-02-19 19:45:50 UTC (rev 2323)
+++ home/phd/SQLObject/paramstyles/sqlobject/main.py 2007-02-19 19:47:10 UTC (rev 2324)
@@ -655,9 +655,9 @@
warnings_level = 1
exception_level = None
# Current levels:
# 1) Actively deprecated in version after 0.6.1 (0.7?); removed after
# 2) Deprecated after 1 (0.8?)
# 3) Deprecated after 2 (0.9?)
def deprecated(message, level=1, stacklevel=2):
if exception_level is not None and exception_level <= level:
@@ -679,8 +679,8 @@
The levels currently mean:
- 1) Deprecated in current version (0.7). Will be removed in next
- version (0.8)
+ 1) Deprecated in current version (0.9). Will be removed in next
+ version (0.10)
2) Planned to deprecate in next version, remove later.
@@ -720,8 +720,8 @@
_parent = None # A reference to the parent instance
childName = None # Children name (to be able to get a subclass)
# moved to sqlmeta in 0.8:
- _parentClass = _sqlmeta_attr('parentClass', 2)
- _childClasses = _sqlmeta_attr('childClasses', 2)
+ _parentClass = _sqlmeta_attr('parentClass', 1)
+ _childClasses = _sqlmeta_attr('childClasses', 1)
# The law of Demeter: the class should not call another classes by name
SelectResultsClass = SelectResults
@@ -756,24 +756,6 @@
cls._SO_finishedClassCreation = False
- if '_columns' in new_attrs and not is_base:
- deprecated(
- 'The _columns attribute you gave (%r) is deprecated; '
- 'columns should be added as class attributes'
- % new_attrs['_columns'], level=1)
- for column in new_attrs['_columns']:
- if isinstance(column, str):
- column = col.Col(column)
- implicitColumns.append(column)
-
- if '_joins' in new_attrs and not is_base:
- deprecated(
- 'The _joins attribute you gave (%r) is deprecated; '
- 'joins should be added as class attributes'
- % new_attrs['_joins'], level=1)
- for j in new_attrs['_joins']:
- implicitJoins.append(j)
-
######################################################
# Set some attributes to their defaults, if necessary.
# First we get the connection:
@@ -828,23 +810,21 @@
classregistry.registry(cls.sqlmeta.registry).addClass(cls)
- _style = _sqlmeta_attr('style', 2)
- _table = _sqlmeta_attr('table', 2)
- _idName = _sqlmeta_attr('idName', 2)
- _lazyUpdate = _sqlmeta_attr('lazyUpdate', 2)
- _defaultOrder = _sqlmeta_attr('defaultOrder', 2)
- _cacheValues = _sqlmeta_attr('cacheValues', 2)
- _registry = _sqlmeta_attr('registry', 2)
- _idType = _sqlmeta_attr('idType', 2)
- _fromDatabase = _sqlmeta_attr('fromDatabase', 2)
+ _style = _sqlmeta_attr('style', 1)
+ _table = _sqlmeta_attr('table', 1)
+ _idName = _sqlmeta_attr('idName', 1)
+ _lazyUpdate = _sqlmeta_attr('lazyUpdate', 1)
+ _defaultOrder = _sqlmeta_attr('defaultOrder', 1)
+ _cacheValues = _sqlmeta_attr('cacheValues', 1)
+ _registry = _sqlmeta_attr('registry', 1)
+ _idType = _sqlmeta_attr('idType', 1)
+ _fromDatabase = _sqlmeta_attr('fromDatabase', 1)
_expired = _sqlmeta_attr('expired', 2)
- _columns = _sqlmeta_attr('columnList', 1)
- _columnDict = _sqlmeta_attr('columns', 1)
- addColumn = _sqlmeta_attr('addColumn', 2)
- delColumn = _sqlmeta_attr('delColumn', 2)
- addJoin = _sqlmeta_attr('addJoin', 2)
- delJoin = _sqlmeta_attr('delJoin', 2)
- addIndex = _sqlmeta_attr('addIndex', 2)
+ addColumn = _sqlmeta_attr('addColumn', 1)
+ delColumn = _sqlmeta_attr('delColumn', 1)
+ addJoin = _sqlmeta_attr('addJoin', 1)
+ delJoin = _sqlmeta_attr('delJoin', 1)
+ addIndex = _sqlmeta_attr('addIndex', 1)
# @classmethod
def _SO_setupSqlmeta(cls, new_attrs, is_base):
@@ -904,7 +884,7 @@
new_name = attr[1:]
deprecated("%r is deprecated; please set the %r "
"attribute in sqlmeta instead" %
- (attr, new_name), level=2,
+ (attr, new_name), level=1,
stacklevel=5)
setattr(cls.sqlmeta, new_name, new_attrs[attr])
delattr(cls, attr)
@@ -912,7 +892,7 @@
if new_attrs.has_key(attr):
deprecated("%r is deprecated and read-only; please do "
"not use it in your classes until it is fully "
- "deprecated" % attr, level=3, stacklevel=5)
+ "deprecated" % attr, level=2, stacklevel=5)
_SO_cleanDeprecatedAttrs = classmethod(_SO_cleanDeprecatedAttrs)
Modified: home/phd/SQLObject/paramstyles/sqlobject/tests/test_auto_old.py
===================================================================
@@ -655,9 +655,9 @@
exception_level = None
# Current levels:
-# 1) Actively deprecated in version after 0.6.1 (0.7?); removed after
-# 2) Deprecated after 1 (0.8?)
-# 3) Deprecated after 2 (0.9?)
+# 1) Actively deprecated in version after 0.9; removed after
+# 2) Deprecated after 1 (0.9?)
+# 3) Deprecated after 2 (0.10?)
def deprecated(message, level=1, stacklevel=2):
if exception_level is not None and exception_level <= level:
--- SQLObject/trunk/sqlobject/main.py 2007-02-18 03:41:19 UTC (rev 2321)
+++ SQLObject/trunk/sqlobject/main.py 2007-02-19 19:41:03 UTC (rev 2322)
@@ -655,9 +655,9 @@
warnings_level = 1
exception_level = None
# Current levels:
# 1) Actively deprecated in version after 0.6.1 (0.7?); removed after
# 2) Deprecated after 1 (0.8?)
# 3) Deprecated after 2 (0.9?)
def deprecated(message, level=1, stacklevel=2):
if exception_level is not None and exception_level <= level:
@@ -679,8 +679,8 @@
The levels currently mean:
- 1) Deprecated in current version (0.7). Will be removed in next
- version (0.8)
+ 1) Deprecated in current version (0.9). Will be removed in next
+ version (0.10)
2) Planned to deprecate in next version, remove later.
@@ -720,8 +720,8 @@
_parent = None # A reference to the parent instance
childName = None # Children name (to be able to get a subclass)
# moved to sqlmeta in 0.8:
- _parentClass = _sqlmeta_attr('parentClass', 2)
- _childClasses = _sqlmeta_attr('childClasses', 2)
+ _parentClass = _sqlmeta_attr('parentClass', 1)
+ _childClasses = _sqlmeta_attr('childClasses', 1)
# The law of Demeter: the class should not call another classes by name
SelectResultsClass = SelectResults
@@ -756,24 +756,6 @@
cls._SO_finishedClassCreation = False
- if '_columns' in new_attrs and not is_base:
- deprecated(
- 'The _columns attribute you gave (%r) is deprecated; '
- 'columns should be added as class attributes'
- % new_attrs['_columns'], level=1)
- for column in new_attrs['_columns']:
- if isinstance(column, str):
- column = col.Col(column)
- implicitColumns.append(column)
-
- if '_joins' in new_attrs and not is_base:
- deprecated(
- 'The _joins attribute you gave (%r) is deprecated; '
- 'joins should be added as class attributes'
- % new_attrs['_joins'], level=1)
- for j in new_attrs['_joins']:
- implicitJoins.append(j)
-
######################################################
# Set some attributes to their defaults, if necessary.
# First we get the connection:
@@ -828,23 +810,21 @@
classregistry.registry(cls.sqlmeta.registry).addClass(cls)
- _style = _sqlmeta_attr('style', 2)
- _table = _sqlmeta_attr('table', 2)
- _idName = _sqlmeta_attr('idName', 2)
- _lazyUpdate = _sqlmeta_attr('lazyUpdate', 2)
- _defaultOrder = _sqlmeta_attr('defaultOrder', 2)
- _cacheValues = _sqlmeta_attr('cacheValues', 2)
- _registry = _sqlmeta_attr('registry', 2)
- _idType = _sqlmeta_attr('idType', 2)
- _fromDatabase = _sqlmeta_attr('fromDatabase', 2)
+ _style = _sqlmeta_attr('style', 1)
+ _table = _sqlmeta_attr('table', 1)
+ _idName = _sqlmeta_attr('idName', 1)
+ _lazyUpdate = _sqlmeta_attr('lazyUpdate', 1)
+ _defaultOrder = _sqlmeta_attr('defaultOrder', 1)
+ _cacheValues = _sqlmeta_attr('cacheValues', 1)
+ _registry = _sqlmeta_attr('registry', 1)
+ _idType = _sqlmeta_attr('idType', 1)
+ _fromDatabase = _sqlmeta_attr('fromDatabase', 1)
_expired = _sqlmeta_attr('expired', 2)
- _columns = _sqlmeta_attr('columnList', 1)
- _columnDict = _sqlmeta_attr('columns', 1)
- addColumn = _sqlmeta_attr('addColumn', 2)
- delColumn = _sqlmeta_attr('delColumn', 2)
- addJoin = _sqlmeta_attr('addJoin', 2)
- delJoin = _sqlmeta_attr('delJoin', 2)
- addIndex = _sqlmeta_attr('addIndex', 2)
+ addColumn = _sqlmeta_attr('addColumn', 1)
+ delColumn = _sqlmeta_attr('delColumn', 1)
+ addJoin = _sqlmeta_attr('addJoin', 1)
+ delJoin = _sqlmeta_attr('delJoin', 1)
+ addIndex = _sqlmeta_attr('addIndex', 1)
# @classmethod
def _SO_setupSqlmeta(cls, new_attrs, is_base):
@@ -904,7 +884,7 @@
new_name = attr[1:]
deprecated("%r is deprecated; please set the %r "
"attribute in sqlmeta instead" %
- (attr, new_name), level=2,
+ (attr, new_name), level=1,
stacklevel=5)
setattr(cls.sqlmeta, new_name, new_attrs[attr])
delattr(cls, attr)
@@ -912,7 +892,7 @@
if new_attrs.has_key(attr):
deprecated("%r is deprecated and read-only; please do "
"not use it in your classes until it is fully "
- "deprecated" % attr, level=3, stacklevel=5)
+ "deprecated" % attr, level=2, stacklevel=5)
_SO_cleanDeprecatedAttrs = classmethod(_SO_cleanDeprecatedAttrs)
Modified: SQLObject/trunk/sqlobject/tests/test_auto_old.py
===================================================================
@@ -655,9 +655,9 @@
exception_level = None
# Current levels:
-# 1) Actively deprecated in version after 0.6.1 (0.7?); removed after
-# 2) Deprecated after 1 (0.8?)
-# 3) Deprecated after 2 (0.9?)
+# 1) Actively deprecated in version after 0.9; removed after
+# 2) Deprecated after 1 (0.9?)
+# 3) Deprecated after 2 (0.10?)
def deprecated(message, level=1, stacklevel=2):
if exception_level is not None and exception_level <= level: